package ch.netzschmiede.flarmradar.api.flarmdata.mock;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

import org.slf4j.Logger;

import ch.netzschmiede.flarmradar.api.flarmdata.IFlarmDataMgrRemote;
import ch.netzschmiede.flarmradar.api.flarmdata.domain.FlarmRecord;
import ch.netzschmiede.flarmradar.api.flarmdata.util.QueryResult;
import ch.netzschmiede.flarmradar.lib.log.FlarmLoggerFactory;

public class FlarmDataMgrMock implements IFlarmDataMgrRemote {
	
	private static Logger log = FlarmLoggerFactory.getLoggerFor(FlarmDataMgrMock.class);
	
	private static HashMap<String, ArrayList<FlarmRecord>> values = new HashMap<String, ArrayList<FlarmRecord>>();

	@Override
	public void write(Date date, String record) {
		FlarmRecord r = new FlarmRecord();
		r.setDate(date);
		r.setRecord(record);
		
		if (null == values.get(date.toString())) {
			ArrayList<FlarmRecord> l = new ArrayList<FlarmRecord>();
			l.add(r);
			values.put(date.toString(), l);
		} else {
			values.get(date.toString()).add(r);
		}
		log.info("Have now " + values.get(date.toString()).size() + " records captured for date " + date.toString());
	}

	@Override
	public void write(Date date, String[] records) {
		for (String record : records) {
			write(date, record);
		}
	}

	@Override
	public QueryResult read(Date date) {
		return read(date, 0, MAX_RESULT_COUNT);
	}

	@Override
	public QueryResult read(Date date, int offset) {
		return read(date, offset, MAX_RESULT_COUNT);
	}

	@Override
	public QueryResult read(Date date, int offset, int resultCount) {
		if (offset < 0) {
			offset = 0;
		}
		if (resultCount > MAX_RESULT_COUNT) {
			resultCount = MAX_RESULT_COUNT;
		}
		
		QueryResult qr = new QueryResult();
		List<FlarmRecord> l = values.get(date.toString());
		if (null == l || offset >= l.size()) {
			return null;
		}
		qr.setTotalCount(l.size());
		
		int lastIdx;
		List<FlarmRecord> chunk;
		if (offset + resultCount < l.size()) {
			lastIdx = offset + resultCount;
			chunk = l.subList(offset, lastIdx);
			qr.setHasMore(true);
			qr.setNextId(lastIdx);
		} else {
			lastIdx = l.size();
			chunk = l.subList(offset, lastIdx);
			qr.setHasMore(false);
		}
		qr.setRecord(chunk.toArray(new FlarmRecord[chunk.size()]));
		
		return qr;
	}

}
